@@ -16,27 +16,40 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.workflows.executions_v1beta import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.workflows.executions_v1beta.services.executions import pagers
 from google.cloud.workflows.executions_v1beta.types import executions
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import ExecutionsTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ExecutionsGrpcAsyncIOTransport
+
 from .client import ExecutionsClient
+from .transports.base import DEFAULT_CLIENT_INFO, ExecutionsTransport
+from .transports.grpc_asyncio import ExecutionsGrpcAsyncIOTransport
 
 
 class ExecutionsAsyncClient:
@@ -158,9 +171,9 @@ class ExecutionsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ExecutionsTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the executions client.
@@ -204,11 +217,11 @@ class ExecutionsAsyncClient:
 
     async def list_executions(
         self,
-        request: Union[executions.ListExecutionsRequest, dict] = None,
+        request: Optional[Union[executions.ListExecutionsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListExecutionsAsyncPager:
         r"""Returns a list of executions which belong to the
@@ -245,7 +258,7 @@ class ExecutionsAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.workflows.executions_v1beta.types.ListExecutionsRequest, dict]):
+            request (Optional[Union[google.cloud.workflows.executions_v1beta.types.ListExecutionsRequest, dict]]):
                 The request object. Request for the
                 [ListExecutions][google.cloud.workflows.executions.v1beta.Executions.ListExecutions]
                 method.
@@ -327,12 +340,12 @@ class ExecutionsAsyncClient:
 
     async def create_execution(
         self,
-        request: Union[executions.CreateExecutionRequest, dict] = None,
+        request: Optional[Union[executions.CreateExecutionRequest, dict]] = None,
         *,
-        parent: str = None,
-        execution: executions.Execution = None,
+        parent: Optional[str] = None,
+        execution: Optional[executions.Execution] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> executions.Execution:
         r"""Creates a new execution using the latest revision of
@@ -365,7 +378,7 @@ class ExecutionsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.workflows.executions_v1beta.types.CreateExecutionRequest, dict]):
+            request (Optional[Union[google.cloud.workflows.executions_v1beta.types.CreateExecutionRequest, dict]]):
                 The request object. Request for the
                 [CreateExecution][google.cloud.workflows.executions.v1beta.Executions.CreateExecution]
                 method.
@@ -443,11 +456,11 @@ class ExecutionsAsyncClient:
 
     async def get_execution(
         self,
-        request: Union[executions.GetExecutionRequest, dict] = None,
+        request: Optional[Union[executions.GetExecutionRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> executions.Execution:
         r"""Returns an execution of the given name.
@@ -479,7 +492,7 @@ class ExecutionsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.workflows.executions_v1beta.types.GetExecutionRequest, dict]):
+            request (Optional[Union[google.cloud.workflows.executions_v1beta.types.GetExecutionRequest, dict]]):
                 The request object. Request for the
                 [GetExecution][google.cloud.workflows.executions.v1beta.Executions.GetExecution]
                 method.
@@ -547,11 +560,11 @@ class ExecutionsAsyncClient:
 
     async def cancel_execution(
         self,
-        request: Union[executions.CancelExecutionRequest, dict] = None,
+        request: Optional[Union[executions.CancelExecutionRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> executions.Execution:
         r"""Cancels an execution of the given name.
@@ -583,7 +596,7 @@ class ExecutionsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.workflows.executions_v1beta.types.CancelExecutionRequest, dict]):
+            request (Optional[Union[google.cloud.workflows.executions_v1beta.types.CancelExecutionRequest, dict]]):
                 The request object. Request for the
                 [CancelExecution][google.cloud.workflows.executions.v1beta.Executions.CancelExecution]
                 method.
@@ -656,14 +669,9 @@ class ExecutionsAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-workflow",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ExecutionsAsyncClient",)
