@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,10 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.workflows.executions.v1beta",
@@ -94,17 +94,51 @@ class Execution(proto.Message):
                 debugging purposes.
         """
 
-        payload = proto.Field(proto.STRING, number=1,)
-        context = proto.Field(proto.STRING, number=2,)
+        payload: str = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        context: str = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
-    name = proto.Field(proto.STRING, number=1,)
-    start_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    state = proto.Field(proto.ENUM, number=4, enum=State,)
-    argument = proto.Field(proto.STRING, number=5,)
-    result = proto.Field(proto.STRING, number=6,)
-    error = proto.Field(proto.MESSAGE, number=7, message=Error,)
-    workflow_revision_id = proto.Field(proto.STRING, number=8,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    start_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    state: State = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=State,
+    )
+    argument: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    result: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    error: Error = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=Error,
+    )
+    workflow_revision_id: str = proto.Field(
+        proto.STRING,
+        number=8,
+    )
 
 
 class ListExecutionsRequest(proto.Message):
@@ -138,10 +172,23 @@ class ListExecutionsRequest(proto.Message):
             will default to the BASIC view.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    view = proto.Field(proto.ENUM, number=4, enum="ExecutionView",)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    view: "ExecutionView" = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum="ExecutionView",
+    )
 
 
 class ListExecutionsResponse(proto.Message):
@@ -150,7 +197,7 @@ class ListExecutionsResponse(proto.Message):
     method.
 
     Attributes:
-        executions (Sequence[google.cloud.workflows.executions_v1beta.types.Execution]):
+        executions (MutableSequence[google.cloud.workflows.executions_v1beta.types.Execution]):
             The executions which match the request.
         next_page_token (str):
             A token, which can be sent as ``page_token`` to retrieve the
@@ -162,8 +209,15 @@ class ListExecutionsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    executions = proto.RepeatedField(proto.MESSAGE, number=1, message="Execution",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    executions: MutableSequence["Execution"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Execution",
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class CreateExecutionRequest(proto.Message):
@@ -182,8 +236,15 @@ class CreateExecutionRequest(proto.Message):
             Required. Execution to be created.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    execution = proto.Field(proto.MESSAGE, number=2, message="Execution",)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    execution: "Execution" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Execution",
+    )
 
 
 class GetExecutionRequest(proto.Message):
@@ -202,8 +263,15 @@ class GetExecutionRequest(proto.Message):
             will default to the FULL view.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    view = proto.Field(proto.ENUM, number=2, enum="ExecutionView",)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    view: "ExecutionView" = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum="ExecutionView",
+    )
 
 
 class CancelExecutionRequest(proto.Message):
@@ -218,7 +286,10 @@ class CancelExecutionRequest(proto.Message):
             projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
